@@ -7,7 +7,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: ethna_handle.php 647 2008-10-04 16:04:39Z mumumu-org $
+ *  @version    $Id: 455069f00aaeccb578d0db2f5de3432adcffcc6a $
  */
 while (ob_get_level()) {
     ob_end_clean();
@@ -17,7 +17,7 @@ $base = dirname(dirname(dirname(__FILE__)));
 ini_set('include_path', $base.PATH_SEPARATOR.ini_get('include_path'));
 
 require_once 'Ethna/Ethna.php';
-require_once ETHNA_BASE . '/class/Ethna_Getopt.php';
+require_once ETHNA_BASE . '/class/Getopt.php';
 
 // fetch arguments
 $opt = new Ethna_Getopt();
@@ -28,37 +28,40 @@ if (Ethna::isError($arg_list)) {
 }
 array_shift($arg_list);  // remove "ethna_handle.php"
 
-$eh =& new Ethna_Handle();
+$eh = new Ethna_Handle();
 
 //  はじめの引数に - が含まれていればそれを分離する
 //  含まれていた場合、それは -v|--version でなければならない
 list($my_arg_list, $arg_list) = _Ethna_HandleGateway_SeparateArgList($arg_list);
 $r = $opt->getopt($my_arg_list, "v", array("version"));
 if (Ethna::isError($r)) {
-    usage($eh);
-    exit(1);
-}
-
-// ad-hoc:(
-foreach ($r[0] as $opt) {
-    if ($opt[0] == "v" || $opt[0] == "--version") {
-        _Ethna_HandleGateway_ShowVersion();
-        exit(2);
+    $id = 'help';
+} else {
+    // ad-hoc:(
+    foreach ($r[0] as $opt) {
+        if ($opt[0] == "v" || $opt[0] == "--version") {
+            _Ethna_HandleGateway_ShowVersion();
+            exit(2);
+        }
     }
 }
 
 if (count($arg_list) == 0) {
-    usage($eh);
-    exit(1);
+    $id = 'help';
+} else {
+    $id = array_shift($arg_list);
 }
 
-$id = array_shift($arg_list);
-
 $handler =& $eh->getHandler($id);
+$handler->eh =& $eh;
 if (Ethna::isError($handler)) {
     printf("no such command: %s\n\n", $id);
-    usage($eh);
-    exit(1);
+    $id = 'help';
+    $handler =& $eh->getHandler($id);
+    $handler->eh =& $eh;
+    if (Ethna::isError($handler)) {
+       exit(1);  //  should not happen.
+    } 
 }
 
 // don't know what will happen:)
@@ -72,21 +75,6 @@ if (Ethna::isError($r)) {
     exit(1);
 }
 
-/**
- *  usage
- */
-function usage(&$eh)
-{
-    $handler_list = $eh->getHandlerList();
-    printf("usage: ethna [option] [command] [args...]\n\n");
-    printf("available options are as follows:\n\n");
-    printf("  -v, --version    show version and exit\n");
-    printf("\navailable commands are as follows:\n\n");
-    foreach ($handler_list as $handler) {
-        printf("  %s -> %s\n", $handler->getId(), $handler->getDescription());
-    }
-}
-
 /**
  *  fetch options for myself
  */
@@ -131,4 +119,3 @@ http://ethna.jp/
 EOD;
     printf($version, ETHNA_VERSION, PHP_VERSION, date('Y'));
 }
-?>
