@@ -4,7 +4,7 @@
  *
  *  @author     {$author}
  *  @package    {$project_id}
- *  @version    $Id: app.url_handler.php 532 2008-05-13 22:41:22Z mumumu-org $
+ *  @version    $Id: 3b358983bac484cec10ba3affe4e7106519a47c2 $
  */
 
 /**
@@ -18,13 +18,16 @@ class {$project_id}_UrlHandler extends Ethna_UrlHandler
 {
     /** @var    array   Action Mapping */
     var $action_map = array(
+        /**
+         * @see http://ethna.jp/ethna-document-dev_guide-urlhandler.html
+         */
         /*
-        'user'  => array(
-            'user_login' => array(
-                'path'          => 'login',
-                'path_regexp'   => false,
-                'path_ext'      => false,
-                'option'        => array(),
+        'index'  => array(                      // UrlHandler's namespace seted in the entry point
+            'user_login' => array(              // key as a action name
+                'path'          => 'login',     // url path
+                'path_regexp'   => false,       // url path setted by regexp
+                'path_ext'      => false,       // parameter/ActionForm map
+                'option'        => array(),     // option
             ),
         ),
          */
@@ -35,9 +38,9 @@ class {$project_id}_UrlHandler extends Ethna_UrlHandler
      *
      *  @access public
      */
-    function &getInstance($class_name = null)
+    public static function getInstance($class_name = null)
     {
-        $instance =& parent::getInstance(__CLASS__);
+        $instance = parent::getInstance(__CLASS__);
         return $instance;
     }
 
@@ -74,4 +77,3 @@ class {$project_id}_UrlHandler extends Ethna_UrlHandler
 }
 
 // vim: foldmethod=marker tabstop=4 shiftwidth=4 autoindent
-?>
